#define VERSION 2
#if (VERSION == 1)
struct C2HS_COND_SENTRY_1;
#else
#endif
int fooC (int, int);

